(function (factory) {
    if (typeof module === "object" && typeof module.exports === "object") {
        var v = factory(require, exports);
        if (v !== undefined) module.exports = v;
    }
    else if (typeof define === "function" && define.amd) {
        define(["require", "exports", "./mappings"], factory);
    }
})(function (require, exports) {
    'use strict';
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.stringToRegex = void 0;
    var mappings_1 = require("./mappings");
    /**
     * @param strong if true, all characters will be converted to
     */
    function mergeMappings(innerMappings, strongMapping) {
        var base = {};
        var codes = !strongMapping ? mappings_1.classicCharCodes : mappings_1.fullCharCodes;
        for (var code in codes) {
            base[code] = codes[code];
        }
        if (innerMappings) {
            for (var mapping in innerMappings) {
                base[mapping] = innerMappings[mapping];
            }
        }
        return base;
    }
    function replacer(input, mappings) {
        return input
            .split('')
            .map(function (letter) {
            for (var mapping in mappings) {
                if (mapping &&
                    mapping !== mappings[mapping] &&
                    (mapping === letter || mappings[mapping].indexOf(letter) !== -1)) {
                    letter = Array.isArray(mappings[mapping]) ? mappings[mapping].join('') : "[" + mappings[mapping] + "]";
                    break;
                }
            }
            return letter;
        })
            .join('');
    }
    /** Generate a function that returns a RegExp, that can be reused with the same options */
    function stringToRegex(options) {
        if (options === void 0) { options = {}; }
        var innerMappings = mergeMappings(typeof options.mappings === 'object' ? options.mappings : null, options.strong);
        return function (input) {
            if (options.spaces) {
                input = input.replace(/\s/g, '').split('').join("(?:\\s|'|-)*");
            }
            return new RegExp(replacer(input, innerMappings).replace(':\\[SsŚśŜŝŞşŠšȘșṠṡṢṣṤṥṦṧṨṩ]', ':\\s'), typeof options.flags === 'string' ? options.flags : 'i');
        };
    }
    exports.stringToRegex = stringToRegex;
});
//# sourceMappingURL=index.js.map